@@ -32,7 +32,6 @@ References:
 
 
 import math
-import warnings
 from abc import abstractmethod
 from typing import Any, Dict, List, Mapping, Optional, Tuple
 
@@ -47,7 +46,7 @@ from botorch.posteriors.fully_bayesian import FullyBayesianPosterior, MCMC_DIM
 from gpytorch.constraints import GreaterThan
 from gpytorch.distributions.multivariate_normal import MultivariateNormal
 from gpytorch.kernels import MaternKernel, ScaleKernel
-from gpytorch.kernels.kernel import Distance, Kernel
+from gpytorch.kernels.kernel import dist, Kernel
 from gpytorch.likelihoods.gaussian_likelihood import (
     FixedNoiseGaussianLikelihood,
     GaussianLikelihood,
@@ -56,26 +55,39 @@ from gpytorch.likelihoods.likelihood import Likelihood
 from gpytorch.means.constant_mean import ConstantMean
 from gpytorch.means.mean import Mean
 from gpytorch.models.exact_gp import ExactGP
-from linear_operator import settings
+from pyro.ops.integrator import register_exception_handler
 from torch import Tensor
 
 MIN_INFERRED_NOISE_LEVEL = 1e-6
 
+_sqrt5 = math.sqrt(5)
+
+
+def _handle_torch_linalg(exception: Exception) -> bool:
+    return type(exception) == torch.linalg.LinAlgError
+
+
+def _handle_valerr_in_dist_init(exception: Exception) -> bool:
+    if not type(exception) == ValueError:
+        return False
+    return "satisfy the constraint PositiveDefinite()" in str(exception)
+
+
+register_exception_handler("torch_linalg", _handle_torch_linalg)
+register_exception_handler("valerr_in_dist_init", _handle_valerr_in_dist_init)
+
 
 def matern52_kernel(X: Tensor, lengthscale: Tensor) -> Tensor:
     """Matern-5/2 kernel."""
-    nu = 5 / 2
     dist = compute_dists(X=X, lengthscale=lengthscale)
-    exp_component = torch.exp(-math.sqrt(nu * 2) * dist)
-    constant_component = (math.sqrt(5) * dist).add(1).add(5.0 / 3.0 * (dist**2))
-    return constant_component * exp_component
+    sqrt5_dist = _sqrt5 * dist
+    return sqrt5_dist.add(1 + 5 / 3 * (dist**2)) * torch.exp(-sqrt5_dist)
 
 
 def compute_dists(X: Tensor, lengthscale: Tensor) -> Tensor:
     """Compute kernel distances."""
-    return Distance()._dist(
-        X / lengthscale, X / lengthscale, postprocess=False, x1_eq_x2=True
-    )
+    scaled_X = X / lengthscale
+    return dist(scaled_X, scaled_X, x1_eq_x2=True)
 
 
 def reshape_and_detach(target: Tensor, new_value: Tensor) -> None:
@@ -83,51 +95,6 @@ def reshape_and_detach(target: Tensor, new_value: Tensor) -> None:
     return new_value.detach().clone().view(target.shape).to(target)
 
 
-def _psd_safe_pyro_mvn_sample(
-    name: str, loc: Tensor, covariance_matrix: Tensor, obs: Tensor
-) -> None:
-    r"""Wraps the `pyro.sample` call in a loop to add an increasing series of jitter
-    to the covariance matrix each time we get a LinAlgError.
-
-    This is modelled after linear_operator's `psd_safe_cholesky`.
-    """
-    jitter = settings.cholesky_jitter.value(loc.dtype)
-    max_tries = settings.cholesky_max_tries.value()
-    for i in range(max_tries + 1):
-        jitter_matrix = (
-            torch.eye(
-                covariance_matrix.shape[-1],
-                device=covariance_matrix.device,
-                dtype=covariance_matrix.dtype,
-            )
-            * jitter
-        )
-        jittered_covar = (
-            covariance_matrix if i == 0 else covariance_matrix + jitter_matrix
-        )
-        try:
-            pyro.sample(
-                name,
-                pyro.distributions.MultivariateNormal(
-                    loc=loc,
-                    covariance_matrix=jittered_covar,
-                ),
-                obs=obs,
-            )
-            return
-        except (torch.linalg.LinAlgError, ValueError) as e:
-            if isinstance(e, ValueError) and "satisfy the constraint" not in str(e):
-                # Not-PSD can be also caught in Distribution.__init__ during parameter
-                # validation, which raises a ValueError. Only catch those errors.
-                raise e
-            jitter = jitter * (10**i)
-            warnings.warn(
-                "Received a linear algebra error while sampling with Pyro. Adding a "
-                f"jitter of {jitter} to the covariance matrix and retrying.",
-                RuntimeWarning,
-            )
-
-
 class PyroModel:
     r"""
     Base class for a Pyro model; used to assist in learning hyperparameters.
@@ -209,12 +176,14 @@ class SaasPyroModel(PyroModel):
         mean = self.sample_mean(**tkwargs)
         noise = self.sample_noise(**tkwargs)
         lengthscale = self.sample_lengthscale(dim=self.ard_num_dims, **tkwargs)
-        k = matern52_kernel(X=self.train_X, lengthscale=lengthscale)
-        k = outputscale * k + noise * torch.eye(self.train_X.shape[0], **tkwargs)
-        _psd_safe_pyro_mvn_sample(
-            name="Y",
-            loc=mean.view(-1).expand(self.train_X.shape[0]),
-            covariance_matrix=k,
+        K = matern52_kernel(X=self.train_X, lengthscale=lengthscale)
+        K = outputscale * K + noise * torch.eye(self.train_X.shape[0], **tkwargs)
+        pyro.sample(
+            "Y",
+            pyro.distributions.MultivariateNormal(
+                loc=mean.view(-1).expand(self.train_X.shape[0]),
+                covariance_matrix=K,
+            ),
             obs=self.train_Y.squeeze(-1),
         )
 
@@ -243,7 +212,7 @@ class SaasPyroModel(PyroModel):
     def sample_noise(self, **tkwargs: Any) -> Tensor:
         r"""Sample the noise variance."""
         if self.train_Yvar is None:
-            return pyro.sample(
+            return MIN_INFERRED_NOISE_LEVEL + pyro.sample(
                 "noise",
                 pyro.distributions.Gamma(
                     torch.tensor(0.9, **tkwargs),
@@ -270,7 +239,7 @@ class SaasPyroModel(PyroModel):
         )
         lengthscale = pyro.deterministic(
             "lengthscale",
-            (1.0 / inv_length_sq).sqrt(),
+            inv_length_sq.rsqrt(),
         )
         return lengthscale
 
@@ -286,7 +255,7 @@ class SaasPyroModel(PyroModel):
             mcmc_samples["kernel_tausq"].unsqueeze(-1)
             * mcmc_samples["_kernel_inv_length_sq"]
         )
-        mcmc_samples["lengthscale"] = (1.0 / inv_length_sq).sqrt()
+        mcmc_samples["lengthscale"] = inv_length_sq.rsqrt()
         # Delete `kernel_tausq` and `_kernel_inv_length_sq` since they aren't loaded
         # into the final model.
         del mcmc_samples["kernel_tausq"], mcmc_samples["_kernel_inv_length_sq"]
