@@ -28,16 +28,6 @@ class DeterministicPosterior(Posterior):
         """
         self.values = values
 
-    @property
-    def base_sample_shape(self) -> torch.Size:
-        r"""The shape of a base sample used for constructing posterior samples.
-
-        This function may be overwritten by subclasses in case `base_sample_shape`
-        and `event_shape` do not agree (e.g. if the posterior is a Multivariate
-        Gaussian that is not full rank).
-        """
-        return torch.Size()
-
     @property
     def device(self) -> torch.device:
         r"""The torch device of the posterior."""
@@ -48,10 +38,13 @@ class DeterministicPosterior(Posterior):
         r"""The torch dtype of the posterior."""
         return self.values.dtype
 
-    @property
-    def event_shape(self) -> torch.Size:
-        r"""The event shape (i.e. the shape of a single sample)."""
-        return self.values.shape
+    def _extended_shape(
+        self, sample_shape: torch.Size = torch.Size()  # noqa: B008
+    ) -> torch.Size:
+        r"""Returns the shape of the samples produced by the posterior with
+        the given `sample_shape`.
+        """
+        return sample_shape + self.values.shape
 
     @property
     def mean(self) -> Tensor:
@@ -69,7 +62,6 @@ class DeterministicPosterior(Posterior):
     def rsample(
         self,
         sample_shape: Optional[torch.Size] = None,
-        base_samples: Optional[Tensor] = None,
     ) -> Tensor:
         r"""Sample from the posterior (with gradients).
 
@@ -80,17 +72,11 @@ class DeterministicPosterior(Posterior):
             sample_shape: A `torch.Size` object specifying the sample shape. To
                 draw `n` samples, set to `torch.Size([n])`. To draw `b` batches
                 of `n` samples each, set to `torch.Size([b, n])`.
-            base_samples: An (optional) Tensor of `N(0, I)` base samples of
-                appropriate dimension, typically obtained from a `Sampler`.
-                Ignored in construction of the samples (used only for shape
-                validation).
 
         Returns:
-            A `sample_shape x event`-dim Tensor of samples from the posterior.
+            Samples from the posterior, a tensor of shape
+            `self._extended_shape(sample_shape=sample_shape)`.
         """
         if sample_shape is None:
             sample_shape = torch.Size([1])
-        if base_samples is not None:
-            if base_samples.shape[: len(sample_shape)] != sample_shape:
-                raise RuntimeError("sample_shape disagrees with shape of base_samples.")
-        return self.values.expand(sample_shape + self.values.shape)
+        return self.values.expand(self._extended_shape(sample_shape))
