@@ -4,24 +4,32 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+from botorch.sampling.base import MCSampler
+from botorch.sampling.get_sampler import get_sampler
+from botorch.sampling.list_sampler import ListSampler
+from botorch.sampling.normal import IIDNormalSampler, SobolQMCNormalSampler
 from botorch.sampling.pairwise_samplers import (
     PairwiseIIDNormalSampler,
     PairwiseMCSampler,
     PairwiseSobolQMCNormalSampler,
 )
 from botorch.sampling.qmc import MultivariateNormalQMCEngine, NormalQMCEngine
-from botorch.sampling.samplers import IIDNormalSampler, MCSampler, SobolQMCNormalSampler
+from botorch.sampling.stochastic_samplers import ForkedRNGSampler, StochasticSampler
 from torch.quasirandom import SobolEngine
 
 
 __all__ = [
+    "ForkedRNGSampler",
+    "get_sampler",
     "IIDNormalSampler",
+    "ListSampler",
     "MCSampler",
     "MultivariateNormalQMCEngine",
     "NormalQMCEngine",
-    "SobolEngine",
-    "SobolQMCNormalSampler",
     "PairwiseIIDNormalSampler",
     "PairwiseMCSampler",
     "PairwiseSobolQMCNormalSampler",
+    "SobolEngine",
+    "SobolQMCNormalSampler",
+    "StochasticSampler",
 ]
